==> style-o-matic-1.1.5.tgz: package/es/components/ToolBar/ToolBar.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, setCorePropTypes, setCorePropDefaults, ROLE } from "../../lib";
import ToolBarContent from "./ToolBarContent.js";
import ToolBarItem from "./ToolBarItem.js";
import ToolBarTitle from "./ToolBarTitle.js";
import ToolBarText from "./ToolBarText.js";
import ToolBarIcon from "./ToolBarIcon.js";
import Button from "../Button/Button.js";
import "./ToolBar.css";

var ToolBar = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBar, _CoreComponent);

  function ToolBar() {
    _classCallCheck(this, ToolBar);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBar.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          return _this2.renderChild(child, inherited);
        }
        return child;
      })
    );
  };

  return ToolBar;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TOOLBAR
}), _class.Content = ToolBarContent, _class.Item = ToolBarItem, _class.Icon = ToolBarIcon, _class.Title = ToolBarTitle, _class.Button = Button, _class.Text = ToolBarText, _temp);


export default ToolBar;

==> style-o-matic-1.1.37.tgz: package/es/components/ToolBar/ToolBar.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, getCorePropTypes, getCorePropDefaults, ROLE } from "../../lib";
import ToolBarContent from "./ToolBarContent.js";
import ToolBarItem from "./ToolBarItem.js";
import ToolBarTitle from "./ToolBarTitle.js";
import ToolBarText from "./ToolBarText.js";
import ToolBarIcon from "./ToolBarIcon.js";
import Button from "../Button/Button.js";
import "./ToolBar.css";

var ToolBar = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBar, _CoreComponent);

  function ToolBar() {
    _classCallCheck(this, ToolBar);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBar.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          return _this2.renderChild(child, inherited);
        }
        return child;
      })
    );
  };

  return ToolBar;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.TOOLBAR
}), _class.Content = ToolBarContent, _class.Item = ToolBarItem, _class.Icon = ToolBarIcon, _class.Title = ToolBarTitle, _class.Button = Button, _class.Text = ToolBarText, _temp);


export default ToolBar;
